==> cnmaps-0.1.1.tar.gz: cnmaps-0.1.1/cnmaps/names.py <==
NAMES = {
    'default': {
        # 数据源：谢栋灿. 高德行政区边界获取与整理（shp格式）[EB/OL]. [2017.11.05]. http://i.xdc.at/2017/11/05/amap-district-to-shapefile/.
        ('皖', '安徽', '安徽省', 'Anhui'):
        'Anhui',
        ('京', '北京', '北京市', 'Beijing'):
        'Beijing',
        ('渝', '重庆', '重庆市', 'Chongqing'):
        'Chongqing',
        ('闽', '福建', '福建省', 'Fujian'):
        'Fujian',
        ('甘', '甘肃', '甘肃省', 'Gansu'):
        'Gansu',
        ('粤', '广东', '广东省', 'Guangdong'):
        'Guangdong',
        ('桂', '广西', '广西省', 'Guangxi'):
        'Guangxi',
        ('贵', '黔', '贵州', '贵州省', 'Guizhou'):
        'Guizhou',
        ('琼', '海南', '海南省', 'Hainan'):
        'Hainan',
        ('冀', '河北', '河北省', 'Hebei'):
        'Hebei',
        ('黑', '黑龙江', '黑龙江省', 'Heilongjiang'):
        'Heilongjiang',
        ('豫', '河南', '河南省', 'Henan'):
        'Henan',
        ('港', '香港', '香港特别行政区', 'HongKong'):
        'HongKong',
        ('鄂', '湖北', '湖北省', 'Hubei'):
        'Hubei',
        ('湘', '湖南', '湖南省', 'Hunan'):
        'Hunan',
        ('蒙', '内蒙古', '内蒙古自治区', 'InnerMongolia'):
        'InnerMongolia',
        ('苏', '江苏', '江苏省', 'Jiangsu'):
        'Jiangsu',
        ('赣', '江西', '江西省', 'Jiangxi'):
        'Jiangxi',
        ('吉', '吉林', '吉林省', 'Jilin'):
        'Jilin',
        ('辽', '辽宁', '辽宁省', 'Liaoning'):
        'Liaoning',
        ('澳', '澳门', '澳门特别行政区', 'Macao'):
        'Macao',
        ('南海', '九段线', 'MaritimeBoundary'):
        'MaritimeBoundary',
        ('中国', '国界线', 'ChinaLand'):
        'ChinaLand',
        ('中国2', '国界线2', 'ChinaLand2'):
        'ChinaLand2',
        ('宁', '宁夏', '宁夏回族自治区', 'Ningxia'):
        'Ningxia',
        ('青', '青海', '青海省', 'Qinghai'):
        'Qinghai',
        ('陕', '陕西', '陕西省', 'Shaanxi'):
        'Shaanxi',
        ('鲁', '山东', '山东省', 'Shandong'):
        'Shandong',
        ('沪', '上海', '上海市', 'Shanghai'):
        'Shanghai',
        ('晋', '山西', '山西省', 'Shanxi'):
        'Shanxi',
        ('川', '四川', '四川省', 'Sichuan'):
        'Sichuan',
        ('津', '天津', '天津市', 'Tianjin'):
        'Tianjin',
        ('藏', '西藏', '西藏自治区', 'Tibet'):
        'Tibet',
        ('新', '新疆', '新疆维吾尔自治区', 'Xinjiang'):
        'Xinjiang',
        ('云', '滇', '云南', '云南省', 'Yunnan'):
        'Yunnan',
        ('浙', '浙江', '浙江省', 'Zhejiang'):
        'Zhejiang',
        ('台', '台湾', '台湾省', 'Taiwan'):
        'Taiwan'
    },
    'geography': {
        # 数据源：张镱锂, 李炳元, 郑度. 青藏高原范围与界线地理信息系统数据[J/DB/OL]. 全球变化数据仓储电子杂志(中英文), 2014. https://doi.org/10.3974/geodb.2014.01.12.V1.
        ('青藏高原', 'TibetanPlateau'):
        'TibetanPlateau',
    }
}

==> cnmaps-0.2.0.tar.gz: cnmaps-0.2.0/cnmaps/names.py <==
NAMES = {
    'default': {
        # 数据源：谢栋灿. 高德行政区边界获取与整理（shp格式）[EB/OL]. [2017.11.05]. http://i.xdc.at/2017/11/05/amap-district-to-shapefile/.
        ('皖', '安徽', '安徽省', 'Anhui'):
        '340000',
        ('京', '北京', '北京市', 'Beijing'):
        '110000',
        ('渝', '重庆', '重庆市', 'Chongqing'):
        '500000',
        ('闽', '福建', '福建省', 'Fujian'):
        '350000',
        ('甘', '甘肃', '甘肃省', 'Gansu'):
        '620000',
        ('粤', '广东', '广东省', 'Guangdong'):
        '440000',
        ('桂', '广西', '广西省', 'Guangxi'):
        '450000',
        ('贵', '黔', '贵州', '贵州省', 'Guizhou'):
        '520000',
        ('琼', '海南', '海南省', 'Hainan'):
        '460000',
        ('冀', '河北', '河北省', 'Hebei'):
        '130000',
        ('黑', '黑龙江', '黑龙江省', 'Heilongjiang'):
        '230000',
        ('豫', '河南', '河南省', 'Henan'):
        '410000',
        ('港', '香港', '香港特别行政区', 'HongKong'):
        '810000',
        ('鄂', '湖北', '湖北省', 'Hubei'):
        '420000',
        ('湘', '湖南', '湖南省', 'Hunan'):
        '430000',
        ('蒙', '内蒙古', '内蒙古自治区', 'InnerMongolia'):
        '150000',
        ('苏', '江苏', '江苏省', 'Jiangsu'):
        '320000',
        ('赣', '江西', '江西省', 'Jiangxi'):
        '360000',
        ('吉', '吉林', '吉林省', 'Jilin'):
        '220000',
        ('辽', '辽宁', '辽宁省', 'Liaoning'):
        '210000',
        ('澳', '澳门', '澳门特别行政区', 'Macao'):
        '820000',
        ('南海', '九段线', 'MaritimeBoundary'):
        'MaritimeBoundary',
        ('中国', '国界线', '简化中国', 'ChinaLand'):
        'ChinaLand',
        ('中国2', '国界线2', '完整中国', 'ChinaLand2'):
        '100000',
        ('宁', '宁夏', '宁夏回族自治区', 'Ningxia'):
        '640000',
        ('青', '青海', '青海省', 'Qinghai'):
        '630000',
        ('陕', '陕西', '陕西省', 'Shaanxi'):
        '610000',
        ('鲁', '山东', '山东省', 'Shandong'):
        '370000',
        ('沪', '上海', '上海市', 'Shanghai'):
        '310000',
        ('晋', '山西', '山西省', 'Shanxi'):
        '140000',
        ('川', '四川', '四川省', 'Sichuan'):
        '510000',
        ('津', '天津', '天津市', 'Tianjin'):
        '120000',
        ('藏', '西藏', '西藏自治区', 'Tibet'):
        '540000',
        ('新', '新疆', '新疆维吾尔自治区', 'Xinjiang'):
        '650000',
        ('云', '滇', '云南', '云南省', 'Yunnan'):
        '530000',
        ('浙', '浙江', '浙江省', 'Zhejiang'):
        '330000',
        ('台', '台湾', '台湾省', 'Taiwan'):
        '710000'
    },
    'geography': {
        # 数据源：张镱锂, 李炳元, 郑度. 青藏高原范围与界线地理信息系统数据[J/DB/OL]. 全球变化数据仓储电子杂志(中英文), 2014. https://doi.org/10.3974/geodb.2014.01.12.V1.
        ('青藏高原', 'TibetanPlateau'):
        'TibetanPlateau',
    }
}
